#!/usr/bin/perl

use strict;
use warnings;

use lib './lib';

require Mail::LMLM;

print $Mail::LMLM::VERSION;

